SwaggerGenerator class

Constructors

SwaggerGenerator()
factory

Properties

gitInformation Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream → ValueStream<Swagger>
no setter
swagger Swagger?
getter/setter pair

Methods

dispose() → void
Close the controller avoid leaking memory
initial(Swagger data, {bool includeResponse = false, List<RegExp> pathParamsRegs = const []}) Future<void>
Initial base swagger document information pathParamsRegs using to get query params from a path. Example: https://example.api/v1/user/1255421 then the lib with create path such as: https://example.api/v1/user/{userId} By default have 2 regex: RegExp(r'0-9+(-)0-9+(-)0-9+(-)0-9+') and RegExp(r'\d+')
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openPreviewPage(BuildContext context) Future
Open a Material page that show preview of swagger.json file and can sync with gitlab
syncToGitlab({required String domain, required String projectId, required String accessToken, required String branch, String message = ''}) Future<bool>
The function using gitlab API to sync swagger.json file to your repo domain your gitlab domain, such as: https:www.git.corporaton.com projectId find it in gitlab repo description accessToken your access token to access into the repo branch branch you wanna put message is optional. If message is empty, default time Iso8601 will be used
toString() String
A string representation of this object.
inherited
updateError(DioError error) → void
Record error then create structure (if not existing) or update structure (if existing)
updateResponse(Response response) → void
Record response then create structure (if not existing) or update structure (if existing)
updateVersion(String value) → void
Update the version of document after initial

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SwaggerGenerator
final