Swagger class
Constructors
-
Swagger({required String id, String openapi = '3.0.3', required SwaggerInfo info, required List<
SwaggerServer> servers, List<SwaggerTag> tags = const [], Map<String, List< paths = const {}, SwaggerComponent? components})SwaggerPath> > -
const
-
Swagger.fromJson(Map<
String, dynamic> json) -
factory
Properties
- components → SwaggerComponent?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- info → SwaggerInfo
-
final
- openapi → String
-
final
-
paths
→ Map<
String, List< SwaggerPath> > -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
servers
→ List<
SwaggerServer> -
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
final
Methods
-
copyWith(
{String? openapi, SwaggerInfo? info, List< SwaggerServer> ? servers, List<SwaggerTag> ? tags, Map<String, List< ? paths, SwaggerComponent? components}) → SwaggerSwaggerPath> > -
merge(
Swagger other) → Swagger -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prettyJson(
) → String -
toSaveObject(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited