SwaggerComponent class

Constructors

SwaggerComponent({List<SwaggerSecurity> securities = const []})
SwaggerComponent now support securitySchemes only, using to make Authentication Reference: https://swagger.io/docs/specification/components/?sbsearch=Component
SwaggerComponent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securities List<SwaggerSecurity>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toSaveObject() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited