SwaggerInfo constructor

const SwaggerInfo({
  1. required String title,
  2. Contact? contact,
  3. required String version,
})

It is considered to be a good practice to include general information about your API into the specification: version number, license notes, contact data, links to documentation, and more https://swagger.io/docs/specification/api-general-info/

Implementation

const SwaggerInfo({
  required this.title,
  this.contact,
  required this.version,
});