SwaggerPath class

Constructors

SwaggerPath({required String path, required String tag, required String method, List<SwaggerResponse> responses = const [], SwaggerContent? requestBody, SwaggerQuery? queryParams, List<Map<String, dynamic>> headers = const [], bool includeResponse = false, String? summary, String? description})
const
SwaggerPath.fromJson(Map<String, dynamic> json)
factory
SwaggerPath.fromResponse(RequestOptions requestOptions, List<SwaggerSecurity> securities, Response? response, {bool includeResponse = false, List<RegExp> pathRegs = const []})
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
headers List<Map<String, dynamic>>
final
includeResponse bool
final
method String
final
path String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
queryParams SwaggerQuery?
final
requestBody SwaggerContent?
final
responses List<SwaggerResponse>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
summary String?
final
tag String
final

Methods

copyWith({String? path, String? tag, String? method, String? summary, List<SwaggerResponse>? responses, SwaggerContent? requestBody, SwaggerQuery? queryParams, List<Map<String, dynamic>>? headers, String? description}) SwaggerPath
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toSaveObject() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
updateResponse(SwaggerPath other) SwaggerPath

Operators

operator ==(Object other) bool
The equality operator.
inherited