Initial base swagger document information
pathParamsRegs using to get query params from a path. Example: https://example.api/v1/user/1255421
then the lib with create path such as: https://example.api/v1/user/{userId}
By default have 2 regex: RegExp(r'0-9+(-)0-9+(-)0-9+(-)0-9+') and RegExp(r'\d+')
The function using gitlab API to sync swagger.json file to your repo
domain your gitlab domain, such as: https:www.git.corporaton.com
projectId find it in gitlab repo description
accessToken your access token to access into the repo
branch branch you wanna put
message is optional. If message is empty, default time Iso8601 will be used