SwaggerInfo class
Constructors
- SwaggerInfo({required String title, Contact? contact, required String version})
-
It is considered to be a good practice to include general information about your API into the specification: version number, license notes, contact data, links to documentation, and more
https://swagger.io/docs/specification/api-general-info/
const
-
SwaggerInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- contact → Contact?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - title → String
-
final
- version → String
-
final
Methods
-
copyWith(
{String? title, Contact? contact, String? version}) → SwaggerInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited