SwaggerSecurity class
Properties
-
bearerFormat
→ String?
-
Optional, arbitrary value for documentation purposes
final
-
description
→ String?
-
Optional, description about this security
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
Display Security name
final
-
position
→ String
-
Where will add the value: query, header, cookie
final
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
scheme
→ String?
-
bearer, basic
final
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
type
→ String
-
http, apiKey, oauth2, openIdConnect
final