SwaggerSecurity class

Constructors

SwaggerSecurity({required String name, String position = 'header', required String type, String? scheme, String? bearerFormat, String? description})
const
SwaggerSecurity.fromJson(Map<String, dynamic> json)
factory

Properties

bearerFormat String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
position String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toSaveObject() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited